package
Version:
v0.0.0-...-bc5e9de
Opens a new window with list of versions in this module.
Published: Aug 7, 2023
License: MIT
Opens a new window with license information.
Imports: 1
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Account struct {
Addr Address `json:"addr"`
PublicKey crypto.PublicKey `json:"public_key"`
Balance int `json:"balance"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.