package
Version:
v0.0.0-...-bc5e9de
Opens a new window with list of versions in this module.
Published: Aug 7, 2023
License: MIT
Opens a new window with license information.
Imports: 5
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
func GenerateGenesisBlock()
AddBlock adds a block to the database.
LastBlock returns the last block in the database.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.